//LabPlot : AverageListDialog.h

#ifndef AVERAGELISTDIALOG_H
#define AVERAGELISTDIALOG_H

#include "ListDialog.h"

class AverageListDialog : public ListDialog
{
	Q_OBJECT
public:
	AverageListDialog(MainWin *mw, const char *name);
public slots:
	void setN(int n) { nle->setText(QString::number(n)); }		//!< set number of points to average
private:
	KLineEdit *nle;
private slots:
	int apply_clicked();
};

#endif // AVERAGELISTDIALOG_H
